@@ -27,7 +27,7 @@ void PDF(double *t, double *a, double *v, double *w, double eps, int *resp, int
       threads[j] = std::thread([=]() {
         for (int i = j*NperThread; i < (j+1)*NperThread; i++) {
           double pm = (resp[i]==1) ? 1.0 : -1.0;
-          // double mp = -1.0*pm;
+          // double mp = -static_cast<double>(pm);
           // double lp = pwiener(t[i], a[i], v[i]*mp, pm*(resp[i]-w[i]), eps, K, epsFLAG);
           double ld = dwiener(t[i]*pm, a[i], v[i], w[i], eps, K, epsFLAG);
           Rlogpdf[i] = ld;
@@ -39,7 +39,7 @@ void PDF(double *t, double *a, double *v, double *w, double eps, int *resp, int
     int last = NperThread * (AmntOfThreads-1);
     for (int i = last; i < N; i++) {
       double pm = (resp[i]==1) ? 1.0 : -1.0;
-      // double mp = -1.0*pm;
+      // double mp = -static_cast<double>(pm);
       // double lp = pwiener(t[i], a[i], v[i]*mp, pm*(resp[i]-w[i]), eps, K, epsFLAG);
       double ld = dwiener(t[i]*pm, a[i], v[i], w[i], eps, K, epsFLAG);
       Rlogpdf[i] = ld;
@@ -54,7 +54,7 @@ void PDF(double *t, double *a, double *v, double *w, double eps, int *resp, int
     /* calculate derivative without parallelization */
     for(int i = 0; i < N; i++) {
       double pm = (resp[i]==1) ? 1.0 : -1.0;
-      // double mp = -1.0*pm;
+      // double mp = -static_cast<double>(pm);
       // double lp = pwiener(t[i], a[i], v[i]*mp, pm*(resp[i]-w[i]), eps, K, epsFLAG);
       double ld = dwiener(t[i]*pm, a[i], v[i], w[i], eps, K, epsFLAG);
       Rlogpdf[i] = ld;
@@ -136,7 +136,7 @@ void dtPDF(double *t, double *a, double *v, double *w, double eps, int *resp, in
         for (int i = j*NperThread; i < (j+1)*NperThread; i++) {
           double pm = (resp[i]==1) ? 1.0 : -1.0;
           double ld = dwiener(t[i]*pm, a[i], v[i], w[i], eps, K, epsFLAG);
-          double mp = -1.0*pm;
+          double mp = -static_cast<double>(pm);
           dtdwiener(t[i], a[i], v[i]*mp, (resp[i]-w[i])*pm, ld, &Rderiv[i], eps, K, epsFLAG);
         }
       });
@@ -146,7 +146,7 @@ void dtPDF(double *t, double *a, double *v, double *w, double eps, int *resp, in
     for (int i = last; i < N; i++) {
       double pm = (resp[i]==1) ? 1.0 : -1.0;
       double ld = dwiener(t[i]*pm, a[i], v[i], w[i], eps, K, epsFLAG);
-      double mp = -1.0*pm;
+      double mp = -static_cast<double>(pm);
       dtdwiener(t[i], a[i], v[i]*mp, (resp[i]-w[i])*pm, ld, &Rderiv[i], eps, K, epsFLAG);
     }
 
@@ -159,7 +159,7 @@ void dtPDF(double *t, double *a, double *v, double *w, double eps, int *resp, in
     for(int i = 0; i < N; i++) {
       double pm = (resp[i]==1) ? 1.0 : -1.0;
       double ld = dwiener(t[i]*pm, a[i], v[i], w[i], eps, K, epsFLAG);
-      double mp = -1.0*pm;
+      double mp = -static_cast<double>(pm);
       dtdwiener(t[i], a[i], v[i]*mp, (resp[i]-w[i])*pm, ld, &Rderiv[i], eps, K, epsFLAG);
     }
   }
@@ -671,7 +671,7 @@ void PDF7(int choice, double *t, int *resp, double *a, double *v, double *t0, do
           Rerr[i] = 0;
           ddiff(choice, t[i], low_or_up, a[i], v[i], t0[i], w[i], sw[i], sv[i], st[i], err, K, epsFLAG, &Rval[i], &Rerr[i]);
           if (choice == 0) {
-            Rlogval[i] = log(Rval[i]);
+            Rlogval[i] = std::log(Rval[i]);
           }
         }
       });
@@ -683,7 +683,7 @@ void PDF7(int choice, double *t, int *resp, double *a, double *v, double *t0, do
       Rerr[i] = 0;
       ddiff(choice, t[i], low_or_up, a[i], v[i], t0[i], w[i], sw[i], sv[i], st[i], err, K, epsFLAG, &Rval[i], &Rerr[i]);
       if (choice == 0) {
-        Rlogval[i] = log(Rval[i]);
+        Rlogval[i] = std::log(Rval[i]);
       }
     }
 
@@ -698,7 +698,7 @@ void PDF7(int choice, double *t, int *resp, double *a, double *v, double *t0, do
       Rerr[i] = 0;
       ddiff(choice, t[i], low_or_up, a[i], v[i], t0[i], w[i], sw[i], sv[i], st[i], err, K, epsFLAG, &Rval[i], &Rerr[i]);
       if (choice == 0) {
-        Rlogval[i] = log(Rval[i]);
+        Rlogval[i] = std::log(Rval[i]);
       }
     }
   }
@@ -727,7 +727,7 @@ void CDF7(int choice, double *t, int *resp, double *a, double *v, double *t0, do
           Rerr[i] = 0;
           pdiff(choice, t[i], low_or_up, a[i], v[i], t0[i], w[i], sw[i], sv[i], st[i], err, K, epsFLAG, &Rval[i], &Rerr[i]);
           if (choice == 0) {
-            Rlogval[i] = log(Rval[i]);
+            Rlogval[i] = std::log(Rval[i]);
           }
         }
       });
@@ -739,7 +739,7 @@ void CDF7(int choice, double *t, int *resp, double *a, double *v, double *t0, do
       Rerr[i] = 0;
       pdiff(choice, t[i], low_or_up, a[i], v[i], t0[i], w[i], sw[i], sv[i], st[i], err, K, epsFLAG, &Rval[i], &Rerr[i]);
       if (choice == 0) {
-        Rlogval[i] = log(Rval[i]);
+        Rlogval[i] = std::log(Rval[i]);
       }
     }
 
@@ -754,7 +754,7 @@ void CDF7(int choice, double *t, int *resp, double *a, double *v, double *t0, do
       Rerr[i] = 0;
       pdiff(choice, t[i], low_or_up, a[i], v[i], t0[i], w[i], sw[i], sv[i], st[i], err, K, epsFLAG, &Rval[i], &Rerr[i]);
       if (choice == 0) {
-        Rlogval[i] = log(Rval[i]);
+        Rlogval[i] = std::log(Rval[i]);
       }
     }
   }
